package Ex5;

# Version.
our $VERSION = 0.01;

1;

=pod

=head1 EXAMPLE1

 # Pragmas.
 use strict;
 use warnings;

 # Print
 print "Foo.\n";

=head1 EXAMPLE2

 # Pragmas.
 use strict;
 use warnings;

 # Print.
 print "Bar.\n";

=cut
